@@ -1,8 +1,10 @@
-# This is file ../spam/R/precmat.R
-# This file is part of the spam package, 
-#      http://www.math.uzh.ch/furrer/software/spam/
-# by Reinhard Furrer [aut, cre], Florian Gerber [ctb]
-     
+# HEADER ####################################################
+# This is file  spam/R/precmat.R.                           #
+# This file is part of the spam package,                    #
+#      http://www.math.uzh.ch/furrer/software/spam/         #
+# by Reinhard Furrer [aut, cre], Florian Gerber [ctb],      #
+#    Daniel Gerber [ctb], Kaspar Moesinger [ctb]            #
+# HEADER END ################################################
 
 
 # construct various precision matrices
@@ -45,7 +47,7 @@ precmat.IGMRFreglat <- function (n, m, order=1, anisotropy = 1)
         kronecker(diag.spam( m), t(Dn)%*%Dn))
 }
 
-precmat.IGMRFirreglat <- function(A, eps= .Spam$eps) {
+precmat.IGMRFirreglat <- function(A, eps= getOption("spam.eps")) {
   if(!is.spam(A)) A <- as.spam(A, eps)
   A@entries <- rep.int(1, length(A))
   test <- isSymmetric.spam(A, tol = eps * 100)
@@ -69,7 +71,7 @@ precmat.RW1 <- function(n) {
 
 precmat.RW2<- function(n) {
   if(n<4)
-    stop("Dimension 'n' should be larger than two")
+    stop("Dimension 'n' should be larger than three")
   Q <- spam(0,n,n)
   Q@entries <- c(-2,1,rep(c(-4,1),n-3),-2)
   Q@colindices <- as.integer( c(rep(2:(n-1),each=2)+c(0,1),n))
@@ -112,3 +114,59 @@ precmat.season <- function(n, season=12) {
 
 }
 
+"precmat.GMRFreglat" <- function(n,m, par=.1, model = "m1p1",  eps = getOption("spam.eps")){
+  if((n<2)|(m<2))
+    stop("n and m need to be >1")
+  dims <- c(n,m)
+  if (model=="m1p1"){
+    x <- numeric(dims[1])
+    x[1:2] <- c(1,-par[1])
+    y <- numeric(prod(dims))
+    y[dims[1]+1] <- -par[1] 
+    return( kronecker(diag.spam(dims[2]), toeplitz.spam(x,eps=eps))+toeplitz.spam(y,eps=eps))
+  }
+  
+  if (model=="m1p2"){
+    x <- numeric(dims[1])
+    x[1:2] <- c(1,-par[1])
+    y <- numeric(prod(dims))
+    y[dims[1]+1] <- -par[2] 
+    return( kronecker(diag.spam(dims[2]), toeplitz.spam(x,eps=eps))+toeplitz.spam(y,eps=eps))
+  }
+  
+  if (model=="m2p3"){
+    x <- numeric(dims[1])
+    x[1:2] <- c(1,-par[1])
+    
+    y <- numeric(dims[1])
+    y[1:2] <- c(-par[2],-par[3])
+
+    z <- numeric(dims[2])
+    z[2] <- 1
+
+
+    p1 <- kronecker( diag.spam(dims[2]), toeplitz.spam(x,eps=eps))
+    p2 <- kronecker( toeplitz.spam(z,eps=eps), toeplitz.spam(y,eps=eps))
+    return( p1 + p2)
+  }
+  if (model=="m2p4"){
+    x <- numeric(dims[1])
+    x[1:2] <- c(1,-par[1])
+    
+    y <- numeric(dims[1])
+    y[1:2] <- c(-par[2],-par[3])
+    w <- numeric(dims[1])
+    w[1:2] <- c(-par[2],-par[4])
+
+    z <- numeric(dims[2])
+    z[2] <- 1
+
+
+    p1 <- kronecker( diag.spam(dims[2]), toeplitz.spam(x,eps=eps))
+    p2 <- kronecker( toeplitz.spam(z,rep(0,dims[2]),eps=eps), toeplitz.spam(y,w,eps=eps))
+    p3 <- kronecker( toeplitz.spam(rep(0,dims[2]),z,eps=eps), toeplitz.spam(w,y,eps=eps))
+    return( p1 + p2 + p3)
+  }
+  stop("Model not implemented yet!")
+
+}
