@@ -1,8 +1,11 @@
-# This is file ../spam/R/s4coerce.R
-# This file is part of the spam package, 
-#      http://www.math.uzh.ch/furrer/software/spam/
-# by Reinhard Furrer [aut, cre], Florian Gerber [ctb]
-     
+# HEADER ####################################################
+# This is file  spam/R/s4coerce.R.                          #
+# This file is part of the spam package,                    #
+#      http://www.math.uzh.ch/furrer/software/spam/         #
+# by Reinhard Furrer [aut, cre], Florian Gerber [ctb],      #
+#    Daniel Gerber [ctb], Kaspar Moesinger [ctb]            #
+# HEADER END ################################################
+
 
 
 # a few coercions that make sense...
@@ -10,7 +13,7 @@
 #      showMethods(coerce)
 
 setAs("spam","logical", def=function(from) {
-    if(.Spam$structurebased) {
+    if(getOption("spam.structurebased")) {
         return( as.logical(from@entries))     
     }else{
         inefficiencywarning( gettextf("This operation may be inefficient"), prod(dim(from)))
@@ -18,7 +21,7 @@ setAs("spam","logical", def=function(from) {
     }})
 
 setAs("spam","vector", def=function(from) {
-    if(.Spam$structurebased) {
+    if(getOption("spam.structurebased")) {
         return( as.vector(from@entries))     
     }else{
         inefficiencywarning( gettextf("This operation may be inefficient"), prod(dim(from)))
@@ -26,7 +29,7 @@ setAs("spam","vector", def=function(from) {
     }})
 
 setAs("spam","integer", def=function(from) {
-    if(.Spam$structurebased) {
+    if(getOption("spam.structurebased")) {
         return( as.integer(from@entries))     
     }else{
         inefficiencywarning( gettextf("This operation may be inefficient"), prod(dim(from)))
