@@ -1,7 +1,7 @@
 # This is file ../spam/tests/demo_article-jss.R
 # This file is part of the spam package, 
 #      http://www.math.uzh.ch/furrer/software/spam/
-# written and maintained by Reinhard Furrer.
+# by Reinhard Furrer [aut, cre], Florian Gerber [ctb]
      
 
 
@@ -247,7 +247,7 @@ Rprof( NULL)
 table[2,4] <- summaryRprof(memory="both")$by.total[rPsx,rPsy]
 
 # Less checking:
-spam.options( safemode=c(FALSE, FALSE, FALSE))
+options(spam.safemode=c(FALSE, FALSE, FALSE))
 Rprof( memory.profiling=TRUE, interval = rPint)
 table[3,1] <- system.time(   for (i in 1:N) ch1 <- chol( gridmat)    )[stsel]
 Rprof( NULL)
@@ -256,11 +256,11 @@ Rprof( memory.profiling=TRUE, interval = rPint)
 table[3,3] <- system.time(   for (i in 1:N) ch2 <- chol( USmat)    )[stsel]
 Rprof( NULL)
 table[3,4] <- summaryRprof(memory="both")$by.total[rPsx,rPsy]
-spam.options( safemode=c(TRUE, TRUE, TRUE))
+options(spam.safemode=c(TRUE, TRUE, TRUE))
 
 
 # lesser checking
-spam.options( cholsymmetrycheck=FALSE)
+options(spam.cholsymmetrycheck=FALSE)
 Rprof( memory.profiling=TRUE, interval = rPint)
 table[4,1] <- system.time(   for (i in 1:N) ch1 <- chol( gridmat)    )[stsel]
 Rprof( NULL)
@@ -270,7 +270,7 @@ Rprof( memory.profiling=TRUE, interval = rPint)
 table[4,3] <- system.time(   for (i in 1:N) ch2 <- chol( USmat)    )[stsel]
 Rprof( NULL)
 table[4,4] <- summaryRprof(memory="both")$by.total[rPsx,rPsy]
-spam.options( cholsymmetrycheck=TRUE)
+options(spam.cholsymmetrycheck=TRUE)
 
 # Pass optimal memory parameters (from above
 memory1 = summary(ch1)[1:2]
@@ -285,7 +285,7 @@ Rprof( NULL)
 table[5,4] <- summaryRprof(memory="both")$by.total[rPsx,rPsy]
 
 # All of the above
-spam.options( cholsymmetrycheck=FALSE, safemode=c(FALSE,FALSE,FALSE))
+options(spam.cholsymmetrycheck=FALSE, safemode=c(FALSE,FALSE,FALSE))
 Rprof( memory.profiling=TRUE, interval = rPint)
 table[6,1] <- system.time(   for (i in 1:N) ch1 <- chol.spam(gridmat,memory=memory1)    )[stsel]
 Rprof( NULL)
@@ -310,7 +310,7 @@ Rprof( NULL)
 table[7,4] <- summaryRprof(memory="both")$by.total[rPsx,rPsy]
 
 # Do not check the permutation
-spam.options( cholpivotcheck=FALSE)
+options(spam.cholpivotcheck=FALSE)
 Rprof( memory.profiling=TRUE, interval = rPint)
 table[8,1] <- system.time(   for (i in 1:N) ch1 <- chol.spam(gridmat,pivot=pivot1,
                                                               memory=memory1)    )[stsel]
@@ -360,7 +360,7 @@ theta.1 <- seq(-.225, to=.515, len=len.1)
 theta.2 <- seq(-.09, to=.235, len=len.2)
 
 grid <- array(NA, c(len.1, len.2))
-spam.options('cholupdatesingular'='null')
+options(spam.cholupdatesingular='null')
 
 for (i in 1:len.1)
   for(j in 1:len.2) 
